/*******************************************************************************
 * Copyright (c) 2005 Chris Aniszczyk.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Chris Aniszczyk - updated to work with EMF
 *    IBM Corporation
 *******************************************************************************/

package org.eclipse.gef.examples.shapes.emf.model.properties;

import java.util.List;

import org.eclipse.gef.examples.shapes.emf.model.Connection;
import org.eclipse.ui.views.properties.ComboBoxPropertyDescriptor;

public class ConnectionPropertySource extends AbstractPropertySource {
	
	private static final String ID_STYLE = "Line Style";
	private static final Integer DASHED = new Integer(0);
	private static final Integer SOLID = new Integer(1);
	
	public ConnectionPropertySource(Object model) {
		super(model);
	}
	
	private Connection getConnectionModel() {
		return (Connection) getModel();
	}
	
	public void createPropertyDescriptors(List descriptors) {
		String values[] = {"Dashed", "Solid"};
		descriptors.add(new ComboBoxPropertyDescriptor(
				ID_STYLE,
				ID_STYLE,
				values));
	}
	
	public Object getPropertyValue(Object id) {
		if(id == ID_STYLE) {
			if(getConnectionModel().isDashed()) {
				return DASHED;
			} else {
				return SOLID;
			}
		}
		return null;
	}
	
	public boolean isPropertySet(Object id) {
		return true;
	}
	
	public void setPropertyValue(Object id, Object value) {
		if(value == null) return;
		if(id == ID_STYLE) {
			Integer intValue = (Integer) value;
			switch(intValue.intValue()) {
			case 0:
				getConnectionModel().setDashed(true);
				break;
			case 1:
				getConnectionModel().setDashed(false);
				break;
			}
		}	
	}
	
}
